@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -46,7 +46,7 @@ void FullSynchronizeResourcesJob::start()
     //Disable cancel button.
     mProgressDialog->setCancelButton(nullptr);
 
-    auto *job = new SynchronizeResourceJob(this);
+    auto job = new SynchronizeResourceJob(this);
     //Full synch
     job->setSynchronizeOnlyCollection(false);
     job->setListResources(mResources);
